@@ -9,28 +9,28 @@
 #include "storeresultjob.h"
 
 #include "maildispatcher_debug.h"
-#include <Akonadi/KMime/AddressAttribute>
-#include <Akonadi/KMime/MessageParts>
-#include <Akonadi/KMime/SpecialMailCollections>
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/AddressAttribute>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/ItemMoveJob>
+#include <Akonadi/MessageParts>
+#include <Akonadi/ServerManager>
+#include <Akonadi/SpecialMailCollections>
+#include <Akonadi/TransportResourceBase>
 #include <KLocalizedString>
 #include <MailTransport/Transport>
 #include <MailTransport/TransportJob>
 #include <MailTransport/TransportManager>
 #include <MailTransportAkonadi/SentBehaviourAttribute>
 #include <MailTransportAkonadi/TransportAttribute>
-#include <QDBusConnection>
-#include <agentinstance.h>
-#include <agentmanager.h>
-#include <collection.h>
-#include <collectionfetchjob.h>
-#include <item.h>
-#include <itemdeletejob.h>
-#include <itemmodifyjob.h>
-#include <itemmovejob.h>
-#include <kmime/kmime_message.h>
-#include <transportresourcebase.h>
 
+#include <KMime/Message>
+
+#include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
 #include <QTimer>
@@ -53,13 +53,14 @@ void SendJob::doTransport()
 
     // Is it an Akonadi transport or a traditional one?
     const TransportAttribute *transportAttribute = mItem.attribute<TransportAttribute>();
+    const auto transport = TransportManager::self()->transportById(transportAttribute->transportId(), false);
     Q_ASSERT(transportAttribute);
-    if (!transportAttribute->transport()) {
+    if (!transport) {
         storeResult(false, i18n("Could not initiate message transport. Possibly invalid transport."));
         return;
     }
 
-    const TransportType type = transportAttribute->transport()->transportType();
+    const TransportType type = transport->transportType();
     if (!type.isValid()) {
         storeResult(false, i18n("Could not send message. Invalid transport."));
         return;
@@ -71,7 +72,7 @@ void SendJob::doTransport()
 
     if (type.isAkonadiResource()) {
         // Send the item directly to the resource that will send it.
-        mResourceId = transportAttribute->transport()->host();
+        mResourceId = transport->host();
         doAkonadiTransport();
     } else {
         // Use a traditional transport job.
@@ -162,12 +163,13 @@ void SendJob::doTraditionalTransport()
     job->setTo(addressAttribute->to());
     job->setCc(addressAttribute->cc());
     job->setBcc(addressAttribute->bcc());
+    job->setDeliveryStatusNotification(addressAttribute->deliveryStatusNotification());
 
     // Signals.
     connect(job, &TransportJob::result, this, &SendJob::transportResult);
-    // Wait kf6 We have a private signal
-    // connect(job, thisOverload<KJob*, ulong>::of(&TransportJob::percent), this, [this](KJob *job,ulong val) {transportPercent(job, val); });
-    connect(job, SIGNAL(percent(KJob *, ulong)), this, SLOT(transportPercent(KJob *, ulong)));
+    connect(job, &TransportJob::percentChanged, this, [this](KJob *job, ulong val) {
+        transportPercent(job, val);
+    });
     job->start();
 }
 
@@ -385,9 +387,7 @@ SendJob::SendJob(const Item &item, QObject *parent)
 {
 }
 
-SendJob::~SendJob()
-{
-}
+SendJob::~SendJob() = default;
 
 void SendJob::start()
 {
