@@ -9,7 +9,7 @@
 #include "maildispatcher_debug.h"
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemModifyJob>
-#include <Akonadi/KMime/MessageFlags>
+#include <Akonadi/MessageFlags>
 #include <KLocalizedString>
 #include <MailTransportAkonadi/DispatchModeAttribute>
 #include <MailTransportAkonadi/ErrorAttribute>
@@ -19,15 +19,13 @@ using namespace MailTransport;
 
 StoreResultJob::StoreResultJob(const Item &item, bool success, const QString &message, QObject *parent)
     : TransactionSequence(parent)
+    , mItem(item)
+    , mSuccess(success)
+    , mMessage(message)
 {
-    mItem = item;
-    mSuccess = success;
-    mMessage = message;
 }
 
-StoreResultJob::~StoreResultJob()
-{
-}
+StoreResultJob::~StoreResultJob() = default;
 
 void StoreResultJob::doStart()
 {
