@@ -38,6 +38,8 @@
 #if HAVE_TEXT_TO_SPEECH_SUPPORT
 #include <QTextToSpeech>
 #endif
+using namespace std::chrono_literals;
+#include <chrono>
 
 using namespace Akonadi;
 
@@ -81,7 +83,7 @@ NewMailNotifierAgent::NewMailNotifierAgent(const QString &id)
     changeRecorder()->ignoreSession(Akonadi::Session::defaultSession());
     changeRecorder()->collectionFetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
     changeRecorder()->setCollectionMonitored(Collection::root(), true);
-    mTimer.setInterval(5 * 1000);
+    mTimer.setInterval(5s); // 5secondes
     connect(&mTimer, &QTimer::timeout, this, &NewMailNotifierAgent::slotShowNotifications);
 
     if (isActive()) {
@@ -158,7 +160,7 @@ void NewMailNotifierAgent::itemsRemoved(const Item::List &items)
         return;
     }
 
-    QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator end(mNewMails.end());
+    const QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator end(mNewMails.end());
     for (QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator it = mNewMails.begin(); it != end; ++it) {
         QList<Akonadi::Item::Id> idList = it.value();
         bool itemFound = false;
@@ -186,7 +188,7 @@ void NewMailNotifierAgent::itemsFlagsChanged(const Akonadi::Item::List &items, c
         return;
     }
     for (const Akonadi::Item &item : items) {
-        QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator end(mNewMails.end());
+        const QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator end(mNewMails.end());
         for (QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::iterator it = mNewMails.begin(); it != end; ++it) {
             QList<Akonadi::Item::Id> idList = it.value();
             if (idList.contains(item.id()) && addedFlags.contains("\\SEEN")) {
@@ -295,7 +297,7 @@ void NewMailNotifierAgent::slotShowNotifications()
             hasUniqMessage = false;
         }
 
-        QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::const_iterator end(mNewMails.constEnd());
+        const QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::const_iterator end(mNewMails.constEnd());
         for (QHash<Akonadi::Collection, QList<Akonadi::Item::Id>>::const_iterator it = mNewMails.constBegin(); it != end; ++it) {
             const auto attr = it.key().attribute<Akonadi::EntityDisplayAttribute>();
             QString displayName;
