@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include <Akonadi/AttributeFactory>
 #include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/CollectionModifyJob>
-#include <Akonadi/KMime/NewMailNotifierAttribute>
+#include <Akonadi/NewMailNotifierAttribute>
 #include <QSortFilterProxyModel>
 
 #include <Akonadi/ChangeRecorder>
@@ -84,6 +84,9 @@ QHash<Akonadi::Collection, bool> NewMailNotifierCollectionProxyModel::notificati
 
 NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWidget *parent)
     : QWidget(parent)
+    , mFolderView(new QTreeView(this))
+    , mChangeRecorder(new Akonadi::ChangeRecorder(this))
+    , mCollectionFilter(new QSortFilterProxyModel(this))
 {
     Akonadi::AttributeFactory::registerAttribute<Akonadi::NewMailNotifierAttribute>();
     auto vbox = new QVBoxLayout(this);
@@ -92,7 +95,6 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     vbox->addWidget(label);
 
     // Create a new change recorder.
-    mChangeRecorder = new Akonadi::ChangeRecorder(this);
     mChangeRecorder->setMimeTypeMonitored(KMime::Message::mimeType());
     mChangeRecorder->fetchCollection(true);
     mChangeRecorder->setAllMonitored(true);
@@ -111,7 +113,6 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     mNewMailNotifierProxyModel = new NewMailNotifierCollectionProxyModel(this);
     mNewMailNotifierProxyModel->setSourceModel(mimeTypeProxy);
 
-    mCollectionFilter = new QSortFilterProxyModel(this);
     mCollectionFilter->setRecursiveFilteringEnabled(true);
     mCollectionFilter->setSourceModel(mNewMailNotifierProxyModel);
     mCollectionFilter->setDynamicSortFilter(true);
@@ -127,7 +128,6 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
 
     vbox->addWidget(searchLine);
 
-    mFolderView = new QTreeView(this);
     mFolderView->setEditTriggers(QAbstractItemView::NoEditTriggers);
     mFolderView->setAlternatingRowColors(true);
     vbox->addWidget(mFolderView);
@@ -147,9 +147,7 @@ NewMailNotifierSelectCollectionWidget::NewMailNotifierSelectCollectionWidget(QWi
     hbox->addStretch(1);
 }
 
-NewMailNotifierSelectCollectionWidget::~NewMailNotifierSelectCollectionWidget()
-{
-}
+NewMailNotifierSelectCollectionWidget::~NewMailNotifierSelectCollectionWidget() = default;
 
 void NewMailNotifierSelectCollectionWidget::slotCollectionTreeFetched()
 {
