@@ -6,10 +6,10 @@
 
 #include "akonadietagcache.h"
 
-#include <collection.h>
-#include <item.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 using namespace KDAV;
 
