@@ -13,7 +13,6 @@
 
 #include "davresource_debug.h"
 #include <KCalendarCore/ICalFormat>
-#include <KIO/DavJob>
 #include <KIO/Job>
 #include <KLocalizedString>
 
@@ -222,7 +221,7 @@ void DavFreeBusyHandler::onRetrieveFreeBusyJobFinished(KJob *job)
     }
 
     if (retrievalJobCount == 0) {
-        QString fbStr = format.createScheduleMessage(mRequestsTracker[email].resultingFreeBusy[requestId], KCalendarCore::iTIPRequest);
+        const QString fbStr = format.createScheduleMessage(mRequestsTracker[email].resultingFreeBusy[requestId], KCalendarCore::iTIPRequest);
         Q_EMIT freeBusyRetrieved(email, fbStr, true, QString());
     }
 }
