@@ -9,7 +9,6 @@
 
 #include "settings.h"
 
-#include "davresource_debug.h"
 #include "settingsadaptor.h"
 #include "utils.h"
 
@@ -40,9 +39,7 @@
 class SettingsHelper
 {
 public:
-    SettingsHelper()
-    {
-    }
+    SettingsHelper() = default;
 
     ~SettingsHelper()
     {
@@ -54,9 +51,7 @@ public:
 
 Q_GLOBAL_STATIC(SettingsHelper, s_globalSettings)
 
-Settings::UrlConfiguration::UrlConfiguration()
-{
-}
+Settings::UrlConfiguration::UrlConfiguration() = default;
 
 Settings::UrlConfiguration::UrlConfiguration(const QString &serialized)
 {
@@ -314,7 +309,7 @@ QString Settings::username(KDAV::Protocol proto, const QString &url) const
             return mUrls[key]->mUser;
         }
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -329,7 +324,7 @@ QString Settings::password(KDAV::Protocol proto, const QString &url)
             return mUrls[key]->mPassword;
         }
     } else {
-        return QString();
+        return {};
     }
 }
 
