@@ -44,29 +44,27 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
 {
     const QString desktopFilePath = wizard->property("providerDesktopFilePath").toString();
     if (desktopFilePath.isEmpty()) {
-        return QString();
+        return {};
     }
 
     KService::Ptr service = KService::serviceByStorageId(desktopFilePath);
     if (!service) {
-        return QString();
+        return {};
     }
 
     const QStringList supportedProtocols = service->property(QStringLiteral("X-DavGroupware-SupportedProtocols")).toStringList();
     if (!supportedProtocols.contains(protocol)) {
-        return QString();
+        return {};
     }
 
-
     const QString pathPropertyName(QStringLiteral("X-DavGroupware-") + protocol + QStringLiteral("Path"));
     if (service->property(pathPropertyName).isNull()) {
-        return QString();
+        return {};
     }
 
-    QString pathPattern;
-    pathPattern.append(service->property(pathPropertyName).toString() + QLatin1Char('/'));
+    QString pathPattern = service->property(pathPropertyName).toString() + QLatin1Char('/');
 
-    QString username = wizard->field(QStringLiteral("credentialsUserName")).toString();
+    const QString username = wizard->field(QStringLiteral("credentialsUserName")).toString();
     QString localPart(username);
     localPart.remove(QRegularExpression(QStringLiteral("@.*$")));
     pathPattern.replace(QLatin1String("$user$"), username);
@@ -75,7 +73,7 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
     if (!service->property(QStringLiteral("X-DavGroupware-Provider")).isNull()) {
         providerName = service->property(QStringLiteral("X-DavGroupware-Provider")).toString();
     }
-    QString localPath = wizard->field(QStringLiteral("installationPath")).toString();
+    const QString localPath = wizard->field(QStringLiteral("installationPath")).toString();
     if (!localPath.isEmpty()) {
         if (providerName == QLatin1String("davical")) {
             if (!localPath.endsWith(QLatin1Char('/'))) {
@@ -100,9 +98,9 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
             url.setScheme(QStringLiteral("http"));
         }
 
-        QString hostPropertyName(QStringLiteral("X-DavGroupware-") + protocol + QStringLiteral("Host"));
+        const QString hostPropertyName(QStringLiteral("X-DavGroupware-") + protocol + QStringLiteral("Host"));
         if (service->property(hostPropertyName).isNull()) {
-            return QString();
+            return {};
         }
 
         url.setHost(service->property(hostPropertyName).toString());
@@ -116,7 +114,7 @@ static QString settingsToUrl(const QWizard *wizard, const QString &protocol)
 
         const QString host = wizard->field(QStringLiteral("connectionHost")).toString();
         if (host.isEmpty()) {
-            return QString();
+            return {};
         }
         const QStringList hostParts = host.split(QLatin1Char(':'));
         url.setHost(hostParts.at(0));
@@ -150,14 +148,14 @@ SetupWizard::SetupWizard(QWidget *parent)
 
 QString SetupWizard::displayName() const
 {
-    QString desktopFilePath = property("providerDesktopFilePath").toString();
+    const QString desktopFilePath = property("providerDesktopFilePath").toString();
     if (desktopFilePath.isEmpty()) {
-        return QString();
+        return {};
     }
 
     KService::Ptr service = KService::serviceByStorageId(desktopFilePath);
     if (!service) {
-        return QString();
+        return {};
     }
 
     return service->name();
@@ -209,17 +207,17 @@ SetupWizard::Url::List SetupWizard::urls() const
 
 CredentialsPage::CredentialsPage(QWidget *parent)
     : QWizardPage(parent)
+    , mUserName(new QLineEdit(this))
+    , mPassword(new KPasswordLineEdit(this))
 {
     setTitle(i18n("Login Credentials"));
     setSubTitle(i18n("Enter your credentials to login to the groupware server"));
 
     auto layout = new QFormLayout(this);
 
-    mUserName = new QLineEdit;
     layout->addRow(i18n("User:"), mUserName);
     registerField(QStringLiteral("credentialsUserName*"), mUserName);
 
-    mPassword = new KPasswordLineEdit;
     mPassword->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
     layout->addRow(i18n("Password:"), mPassword);
     registerField(QStringLiteral("credentialsPassword*"), mPassword, "password", SIGNAL(passwordChanged(QString)));
@@ -253,24 +251,24 @@ int CredentialsPage::nextId() const
 
 PredefinedProviderPage::PredefinedProviderPage(QWidget *parent)
     : QWizardPage(parent)
+    , mLabel(new QLabel(this))
+    , mProviderGroup(new QButtonGroup(this))
+    , mUseProvider(new QRadioButton(this))
+    , mDontUseProvider(new QRadioButton(i18n("No, choose another server"), this))
 {
     setTitle(i18n("Predefined provider found"));
     setSubTitle(i18n("Select if you want to use the auto-detected provider"));
 
     auto layout = new QVBoxLayout(this);
 
-    mLabel = new QLabel;
     layout->addWidget(mLabel);
 
-    mProviderGroup = new QButtonGroup(this);
     mProviderGroup->setExclusive(true);
 
-    mUseProvider = new QRadioButton;
     mProviderGroup->addButton(mUseProvider);
     mUseProvider->setChecked(true);
     layout->addWidget(mUseProvider);
 
-    mDontUseProvider = new QRadioButton(i18n("No, choose another server"));
     mProviderGroup->addButton(mDontUseProvider);
     layout->addWidget(mDontUseProvider);
 }
@@ -340,7 +338,7 @@ ServerTypePage::ServerTypePage(QWidget *parent)
     mServerGroup->setExclusive(true);
 
     auto hLayout = new QHBoxLayout;
-    auto button = new QRadioButton(i18n("Use one of those servers:"));
+    auto button = new QRadioButton(i18n("Use one of those servers:"), this);
     registerField(QStringLiteral("templateConfiguration"), button);
     mServerGroup->addButton(button);
     mServerGroup->setId(button, 0);
@@ -349,7 +347,7 @@ ServerTypePage::ServerTypePage(QWidget *parent)
     hLayout->addWidget(mProvidersCombo);
     layout->addLayout(hLayout);
 
-    button = new QRadioButton(i18n("Configure the resource manually"));
+    button = new QRadioButton(i18n("Configure the resource manually"), this);
     connect(button, &QRadioButton::toggled, this, &ServerTypePage::manualConfigToggled);
     registerField(QStringLiteral("manualConfiguration"), button);
     mServerGroup->addButton(button);
@@ -501,6 +499,7 @@ void ConnectionPage::urlElementChanged()
 
 CheckPage::CheckPage(QWidget *parent)
     : QWizardPage(parent)
+    , mStatusLabel(new QTextBrowser(this))
 {
     setTitle(i18n("Test Connection"));
     setSubTitle(i18n("You can test now whether the groupware server can be accessed with the current configuration"));
@@ -508,10 +507,9 @@ CheckPage::CheckPage(QWidget *parent)
 
     auto layout = new QVBoxLayout(this);
 
-    auto button = new QPushButton(i18n("Test Connection"));
+    auto button = new QPushButton(i18n("Test Connection"), this);
     layout->addWidget(button);
 
-    mStatusLabel = new QTextBrowser;
     layout->addWidget(mStatusLabel);
 
     connect(button, &QRadioButton::clicked, this, &CheckPage::checkConnection);
