@@ -6,18 +6,21 @@
 
 #include "urlconfigurationdialog.h"
 
-#include "settings.h"
 #include <KDAV/DavCollectionModifyJob>
 #include <KDAV/DavCollectionsFetchJob>
 
 #include <KAuthorized>
+#include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <KSharedConfig>
 
+#include <KWindowConfig>
 #include <QButtonGroup>
 #include <QStandardItem>
 #include <QStandardItemModel>
 #include <QVBoxLayout>
+#include <QWindow>
 
 UrlConfigurationDialog::UrlConfigurationDialog(QWidget *parent)
     : QDialog(parent)
@@ -69,17 +72,17 @@ UrlConfigurationDialog::~UrlConfigurationDialog()
 
 void UrlConfigurationDialog::readConfig()
 {
-    KConfigGroup grp(KSharedConfig::openStateConfig(), "UrlConfigurationDialog");
-    const QSize size = grp.readEntry("Size", QSize(300, 200));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(300, 200));
+    KConfigGroup group(KSharedConfig::openStateConfig(), "UrlConfigurationDialog");
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void UrlConfigurationDialog::writeConfig()
 {
     KConfigGroup grp(KSharedConfig::openStateConfig(), "UrlConfigurationDialog");
-    grp.writeEntry("Size", size());
+    KWindowConfig::saveWindowSize(windowHandle(), grp);
     grp.sync();
 }
 
@@ -240,7 +243,7 @@ void UrlConfigurationDialog::onModelDataChanged(const QModelIndex &topLeft, cons
     QUrl fullUrl(url);
     fullUrl.setUserInfo(QString());
 
-    KDAV::DavUrl davUrl(fullUrl, protocol());
+    const KDAV::DavUrl davUrl(fullUrl, protocol());
     auto job = new KDAV::DavCollectionModifyJob(davUrl);
     job->setProperty(QStringLiteral("displayname"), newName);
     connect(job, &KDAV::DavCollectionModifyJob::result, this, &UrlConfigurationDialog::onChangeDisplayNameFinished);
