@@ -6,11 +6,11 @@
 
 #include "entriesfetchjob.h"
 
-#include <AkonadiCore/CollectionModifyJob>
+#include <Akonadi/CollectionModifyJob>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Todo>
+#include <KContacts/Addressee>
 #include <QtConcurrent>
-#include <kcontacts/addressee.h>
 
 #include "etesync_debug.h"
 #include "settings.h"
