@@ -9,7 +9,6 @@
 #include <QTemporaryFile>
 
 #include "ewsclient_debug.h"
-#include "ewsxml.h"
 
 static constexpr uint respChunkTimeout = 250; /* ms */
 
@@ -22,9 +21,7 @@ EwsGetStreamingEventsRequest::EwsGetStreamingEventsRequest(EwsClient &client, QO
     connect(&mRespTimer, &QTimer::timeout, this, &EwsGetStreamingEventsRequest::requestDataTimeout);
 }
 
-EwsGetStreamingEventsRequest::~EwsGetStreamingEventsRequest()
-{
-}
+EwsGetStreamingEventsRequest::~EwsGetStreamingEventsRequest() = default;
 
 void EwsGetStreamingEventsRequest::start()
 {
