@@ -21,7 +21,6 @@
 #include <Akonadi/SpecialMailCollections>
 #include <KMime/Message>
 #include <KNotification>
-#include <KWallet>
 
 #include <KLocalizedString>
 
@@ -29,7 +28,7 @@
 #include "ewsconfigdialog.h"
 #include "ewscreatefolderrequest.h"
 #include "ewscreateitemjob.h"
-#ifdef HAVE_SEPARATE_MTA_RESOURCE
+#if HAVE_SEPARATE_MTA_RESOURCE
 #include "ewscreateitemrequest.h"
 #endif
 #include "ewsdeletefolderrequest.h"
@@ -49,7 +48,6 @@
 #include "ewssubscriptionmanager.h"
 #include "ewssyncstateattribute.h"
 #include "ewsupdatefolderrequest.h"
-#include "ewsupdateitemrequest.h"
 #include "tags/ewsglobaltagsreadjob.h"
 #include "tags/ewsglobaltagswritejob.h"
 #include "tags/ewstagstore.h"
@@ -1020,7 +1018,7 @@ void EwsResource::itemSendRequestFinished(KJob *job)
 
 void EwsResource::sendMessage(const QString &id, const QByteArray &content)
 {
-#ifdef HAVE_SEPARATE_MTA_RESOURCE
+#if HAVE_SEPARATE_MTA_RESOURCE
     auto req = new EwsCreateItemRequest(mEwsClient, this);
 
     EwsItem item;
@@ -1034,7 +1032,7 @@ void EwsResource::sendMessage(const QString &id, const QByteArray &content)
 #endif
 }
 
-#ifdef HAVE_SEPARATE_MTA_RESOURCE
+#if HAVE_SEPARATE_MTA_RESOURCE
 void EwsResource::messageSendRequestFinished(KJob *job)
 {
     QString id = job->property("requestId").toString();
@@ -1404,7 +1402,6 @@ void EwsResource::reauthenticate()
     case AuthFailure:
         break;
     }
-
 }
 
 void EwsResource::requestAuthFailed()
