@@ -6,7 +6,7 @@
 
 #include "ewsmodifymailjob.h"
 
-#include <Akonadi/KMime/MessageFlags>
+#include <Akonadi/MessageFlags>
 
 #include <KLocalizedString>
 
@@ -24,9 +24,7 @@ EwsModifyMailJob::EwsModifyMailJob(EwsClient &client, const Akonadi::Item::List
 {
 }
 
-EwsModifyMailJob::~EwsModifyMailJob()
-{
-}
+EwsModifyMailJob::~EwsModifyMailJob() = default;
 
 void EwsModifyMailJob::start()
 {
