@@ -9,7 +9,6 @@
 #include <Akonadi/Collection>
 
 #include "ewsid.h"
-#include "ewsitemhandler.h"
 #include "ewsresource.h"
 #include "ewstagstore.h"
 #include "ewsupdatefolderrequest.h"
@@ -24,9 +23,7 @@ EwsGlobalTagsWriteJob::EwsGlobalTagsWriteJob(EwsTagStore *tagStore, EwsClient &c
 {
 }
 
-EwsGlobalTagsWriteJob::~EwsGlobalTagsWriteJob()
-{
-}
+EwsGlobalTagsWriteJob::~EwsGlobalTagsWriteJob() = default;
 
 void EwsGlobalTagsWriteJob::start()
 {
