@@ -33,6 +33,7 @@ class GoogleSettings : public SettingsBase
 
 public:
     GoogleSettings();
+    void init();
     void setWindowId(WId id);
     void setResourceId(const QString &resourceIdentifier);
 
@@ -51,10 +52,9 @@ public:
 Q_SIGNALS:
     void accountReady(bool ready);
     void accountChanged();
-private Q_SLOTS:
-    void slotWalletOpened(bool success);
 
 private:
+    void slotWalletOpened(bool success);
     WId m_winId = 0;
     QString m_resourceId;
     bool m_isReady = false;
