@@ -8,7 +8,6 @@
 #include "icalresource.h"
 
 #include <KCalendarCore/FreeBusy>
-#include <KCalendarCore/MemoryCalendar>
 
 #include <KLocalizedString>
 #include <QDebug>
@@ -31,9 +30,7 @@ ICalResource::ICalResource(const QString &id, const QStringList &mimeTypes, cons
     initialise(mimeTypes, icon);
 }
 
-ICalResource::~ICalResource()
-{
-}
+ICalResource::~ICalResource() = default;
 
 bool ICalResource::doRetrieveItems(const Akonadi::Item::List &items, const QSet<QByteArray> &parts)
 {
@@ -49,7 +46,6 @@ bool ICalResource::doRetrieveItems(const Akonadi::Item::List &items, const QSet<
             qCritical() << "akonadi_ical_resource: Can't find incidence with uid " << rid << "; item.id() = " << item.id();
             Q_EMIT error(i18n("Incidence with uid '%1' not found.", rid));
             return false;
-            ;
         }
 
         Incidence::Ptr incidencePtr(incidence->clone());
