@@ -66,8 +66,6 @@
 
 #include "imapflags.h"
 #include "sessionpool.h"
-#include "sessionuiproxy.h"
-#include "settingspasswordrequester.h"
 
 #include "resourceadaptor.h"
 
@@ -85,7 +83,6 @@ ImapResourceBase::ImapResourceBase(const QString &id)
     : ResourceBase(id)
     , m_pool(new SessionPool(2, this))
     , m_settings(nullptr)
-    , m_idle(nullptr)
 {
     QTimer::singleShot(0, this, &ImapResourceBase::updateResourceName);
 
