@@ -21,7 +21,7 @@
 #include <Akonadi/CollectionStatistics>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
-#include <Akonadi/KMime/MessageParts>
+#include <Akonadi/MessageParts>
 #include <Akonadi/Session>
 
 #include "imapresource_debug.h"
@@ -40,9 +40,7 @@ RetrieveItemsTask::RetrieveItemsTask(const ResourceStateInterface::Ptr &resource
 {
 }
 
-RetrieveItemsTask::~RetrieveItemsTask()
-{
-}
+RetrieveItemsTask::~RetrieveItemsTask() = default;
 
 void RetrieveItemsTask::setFetchMissingItemBodies(bool enabled)
 {
