@@ -58,16 +58,16 @@ public:
 
     void setClientId(const QByteArray &clientId);
 
-    bool isConnected() const;
+    Q_REQUIRED_RESULT bool isConnected() const;
     bool connect(ImapAccount *account);
     void disconnect(SessionTermination termination = LogoutSession);
 
-    qint64 requestSession();
+    Q_REQUIRED_RESULT qint64 requestSession();
     void cancelSessionRequest(qint64 id);
     void releaseSession(KIMAP::Session *session);
 
     ImapAccount *account() const;
-    QStringList serverCapabilities() const;
+    Q_REQUIRED_RESULT QStringList serverCapabilities() const;
     QList<KIMAP::MailBoxDescriptor> serverNamespaces() const;
     enum Namespace {
         Personal,
@@ -123,4 +123,3 @@ private:
     QList<KIMAP::MailBoxDescriptor> m_sharedNamespaces;
     QByteArray m_clientId;
 };
-
