@@ -20,7 +20,6 @@
 #include "imapresource.h"
 #include "serverinfodialog.h"
 #include "settings.h"
-#include "utils.h"
 #include <config-imap.h>
 
 #include <Libkdepim/LineEditCatchReturnKey>
@@ -33,15 +32,19 @@
 #include <Akonadi/CollectionFetchJob>
 #include <Akonadi/CollectionModifyJob>
 #include <Akonadi/EntityDisplayAttribute>
-#include <Akonadi/KMime/SpecialMailCollections>
-#include <Akonadi/KMime/SpecialMailCollectionsRequestJob>
 #include <Akonadi/ResourceSettings>
+#include <Akonadi/SpecialMailCollections>
+#include <Akonadi/SpecialMailCollectionsRequestJob>
 #include <KAuthorized>
 #include <KEMailSettings>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KUser>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QNetworkInformation>
+#else
 #include <QNetworkConfigurationManager>
+#endif
 #include <QPushButton>
 
 #include <KIdentityManagement/IdentityCombo>
@@ -80,7 +83,7 @@ static QString authenticationModeString(MailTransport::Transport::EnumAuthentica
     default:
         break;
     }
-    return QString();
+    return {};
 }
 
 static void setCurrentAuthMode(QComboBox *authCombo, MailTransport::Transport::EnumAuthenticationType::type authtype)
@@ -119,7 +122,9 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
     , m_ui(new Ui::SetupServerView)
     , mValidator(this)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     auto networkConfigMgr = new QNetworkConfigurationManager(QCoreApplication::instance());
+#endif
 
     m_parentResource->settings()->setWinId(parent);
     auto mainWidget = new QWidget(this);
@@ -193,7 +198,19 @@ SetupServer::SetupServer(ImapResourceBase *parentResource, WId parent)
     slotTestChanged();
     slotComplete();
     slotCustomSieveChanged();
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
+    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
     connect(networkConfigMgr, &QNetworkConfigurationManager::onlineStateChanged, this, &SetupServer::slotTestChanged);
+    QT_WARNING_POP
+#else
+    QNetworkInformation::instance()->load(QNetworkInformation::Feature::Reachability);
+    connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, [this](QNetworkInformation::Reachability newReachability) {
+        slotTestChanged();
+    });
+#endif
 }
 
 SetupServer::~SetupServer()
@@ -535,7 +552,7 @@ void SetupServer::slotFinished(const QVector<int> &testResult)
     using namespace MailTransport;
 
     if (!m_serverTest->isNormalPossible() && !m_serverTest->isSecurePossible()) {
-        KMessageBox::sorry(this, i18n("Unable to connect to the server, please verify the server address."));
+        KMessageBox::error(this, i18n("Unable to connect to the server, please verify the server address."));
     }
 
     m_ui->testInfo->show();
