@@ -7,7 +7,7 @@
 #include "kolabconversion.h"
 #include "commonconversion.h"
 
-#include <Akonadi/Notes/NoteUtils>
+#include <Akonadi/NoteUtils>
 
 namespace Kolab
 {
@@ -42,7 +42,7 @@ Note fromNote(const KMime::Message::Ptr &m)
     std::vector<Kolab::CustomProperty> customs;
     QMap<QString, QString> &customsMap = note.custom();
     for (QMap<QString, QString>::const_iterator it = customsMap.constBegin(), end = customsMap.constEnd(); it != end; ++it) {
-        customs.push_back(Kolab::CustomProperty(toStdString(it.key()), toStdString(it.value())));
+        customs.emplace_back(toStdString(it.key()), toStdString(it.value()));
     }
     n.setCustomProperties(customs);
 
