@@ -9,7 +9,7 @@
 #include "pimkolab_debug.h"
 #include <KContacts/Addressee>
 #include <QFile>
-#include <float.h>
+#include <cfloat>
 
 using namespace KolabV2;
 
@@ -45,14 +45,11 @@ Contact::Contact(const KContacts::Addressee *addr)
 
 // loading (xml->addressee)
 Contact::Contact(const QString &xml)
-    : mHasGeo(false)
 {
     load(xml);
 }
 
-Contact::~Contact()
-{
-}
+Contact::~Contact() = default;
 
 void Contact::setGivenName(const QString &name)
 {
