@@ -17,11 +17,8 @@
 #include "pimkolab/kolabformat/kolabobject.h"
 
 #include <Akonadi/TagModifyJob>
-#include <KIMAP/AppendJob>
 #include <KIMAP/SearchJob>
-#include <KIMAP/SelectJob>
 #include <KIMAP/Session>
-#include <KIMAP/StoreJob>
 #include <replacemessagejob.h>
 
 KMime::Message::Ptr TagConverter::createMessage(const Akonadi::Tag &tag, const Akonadi::Item::List &items, const QString &username)
@@ -42,11 +39,9 @@ KMime::Message::Ptr TagConverter::createMessage(const Akonadi::Tag &tag, const A
 }
 
 struct TagMerger : public Merger {
-    ~TagMerger() override
-    {
-    }
+    ~TagMerger() override = default;
 
-    KMime::Message::Ptr merge(const KMime::Message::Ptr &newMessage, const QList<KMime::Message::Ptr> &conflictingMessages) const override
+    Q_REQUIRED_RESULT KMime::Message::Ptr merge(const KMime::Message::Ptr &newMessage, const QList<KMime::Message::Ptr> &conflictingMessages) const override
     {
         qCDebug(KOLABRESOURCE_LOG) << "Got " << conflictingMessages.size() << " conflicting relation configuration objects. Overwriting with local version.";
         return newMessage;
