@@ -16,8 +16,9 @@
 
 #include "libmaildir/maildir.h"
 
-#include <kmbox/mbox.h>
-#include <kmime/kmime_message.h>
+#include <KMbox/MBox>
+
+#include <KMime/Message>
 
 #include <QRandomGenerator>
 #include <QTemporaryDir>
@@ -80,7 +81,7 @@ public:
         qRegisterMetaType<Akonadi::Item::List>();
     }
 
-    ~ItemDeleteTest()
+    ~ItemDeleteTest() override
     {
         delete mStore;
         delete mDir;
@@ -126,7 +127,8 @@ void ItemDeleteTest::testMaildir()
     KPIM::Maildir md1 = topLevelMd.subFolder(QStringLiteral("collection1"));
     QVERIFY(md1.isValid());
 
-    QSet<QString> entrySet1 = QSet<QString>::fromList(md1.entryList());
+    QStringList md1EntryList = md1.entryList();
+    QSet<QString> entrySet1(md1EntryList.cbegin(), md1EntryList.cend());
     QCOMPARE((int)entrySet1.count(), 4);
 
     mStore->setPath(topDir.path());
@@ -157,7 +159,8 @@ void ItemDeleteTest::testMaildir()
     Item item = job->item();
     QCOMPARE(item.id(), item1.id());
 
-    entrySet = QSet<QString>::fromList(md1.entryList());
+    md1EntryList = md1.entryList();
+    entrySet = QSet<QString>(md1EntryList.cbegin(), md1EntryList.cend());
     QCOMPARE((int)entrySet.count(), 3);
 
     delIdSet = entrySet1.subtract(entrySet);
@@ -364,7 +367,8 @@ void ItemDeleteTest::testCachePreservation()
     KPIM::Maildir md1 = topLevelMd.subFolder(QStringLiteral("collection1"));
     QVERIFY(md1.isValid());
 
-    QSet<QString> entrySet1 = QSet<QString>::fromList(md1.entryList());
+    const QStringList md1EntryList = md1.entryList();
+    QSet<QString> entrySet1(md1EntryList.cbegin(), md1EntryList.cend());
     QCOMPARE((int)entrySet1.count(), 4);
 
     QFileInfo fileInfo2(topDir.path(), QStringLiteral("collection2"));
@@ -430,7 +434,7 @@ void ItemDeleteTest::testCachePreservation()
 
     // TODO since we don't know which message we've deleted, we can only check if some flags are present
     int flagCountTotal = 0;
-    Q_FOREACH (int count, flagCounts) {
+    for (int count : std::as_const(flagCounts)) {
         flagCountTotal += count;
     }
     QVERIFY(flagCountTotal > 0);
@@ -506,7 +510,8 @@ void ItemDeleteTest::testExpectedFailure()
     KPIM::Maildir md1 = topLevelMd.subFolder(QStringLiteral("collection1"));
     QVERIFY(md1.isValid());
 
-    QSet<QString> entrySet1 = QSet<QString>::fromList(md1.entryList());
+    const QStringList md1EntryList = md1.entryList();
+    QSet<QString> entrySet1(md1EntryList.cbegin(), md1EntryList.cend());
     QCOMPARE((int)entrySet1.count(), 4);
 
     QFileInfo fileInfo2(topDir.path(), QStringLiteral("collection2"));
