@@ -28,18 +28,17 @@ public:
 
     void setRemoteId(const QString &remoteId);
 
-    QString remoteId() const;
+    Q_REQUIRED_RESULT QString remoteId() const;
 
     void setRemoteRevision(const QString &remoteRev);
 
-    QString remoteRevision() const;
+    Q_REQUIRED_RESULT QString remoteRevision() const;
 
-public:
-    QByteArray type() const override;
+    Q_REQUIRED_RESULT QByteArray type() const override;
 
     EntityCompactChangeAttribute *clone() const override;
 
-    QByteArray serialized() const override;
+    Q_REQUIRED_RESULT QByteArray serialized() const override;
 
     void deserialize(const QByteArray &data) override;
 
@@ -50,4 +49,3 @@ private:
 };
 }
 }
-
