@@ -32,7 +32,7 @@ public:
 
     ~ItemDeleteJob() override;
 
-    Item item() const;
+    Q_REQUIRED_RESULT Item item() const;
 
     bool accept(Visitor *visitor) override;
 
@@ -44,4 +44,3 @@ private:
 };
 }
 }
-
