@@ -10,10 +10,10 @@
 
 using namespace Akonadi;
 
-class FileStore::ItemModifyJob::Private
+class FileStore::ItemModifyJobPrivate
 {
 public:
-    Private()
+    ItemModifyJobPrivate()
         : mIgnorePayload(false)
     {
     }
@@ -25,17 +25,14 @@ public:
 
 FileStore::ItemModifyJob::ItemModifyJob(const Item &item, FileStore::AbstractJobSession *session)
     : FileStore::Job(session)
-    , d(new Private())
+    , d(new ItemModifyJobPrivate())
 {
     d->mItem = item;
 
     session->addJob(this);
 }
 
-FileStore::ItemModifyJob::~ItemModifyJob()
-{
-    delete d;
-}
+FileStore::ItemModifyJob::~ItemModifyJob() = default;
 
 void FileStore::ItemModifyJob::setIgnorePayload(bool ignorePayload)
 {
