@@ -6,12 +6,12 @@
 
 #include "tomboyitemsdownloadjob.h"
 #include "debug.h"
-#include <Akonadi/Notes/NoteUtils>
+#include <Akonadi/NoteUtils>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
 
-TomboyItemsDownloadJob::TomboyItemsDownloadJob(Akonadi::Collection::Id id, KIO::AccessManager *manager, QObject *parent)
+TomboyItemsDownloadJob::TomboyItemsDownloadJob(Akonadi::Collection::Id id, KIO::Integration::AccessManager *manager, QObject *parent)
     : TomboyJobBase(manager, parent)
     , mCollectionId(id)
 {
