@@ -1,6 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2016 Stefan Stäglich <sstaeglich@kdemail.net>
-    SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,7 +17,7 @@ TomboyNotesConfigWidget::TomboyNotesConfigWidget(const KSharedConfigPtr &config,
 {
     Settings::instance(config);
 
-    QWidget *mainWidget = new QWidget(parent);
+    auto *mainWidget = new QWidget(parent);
     ui->setupUi(mainWidget);
     parent->layout()->addWidget(mainWidget);
 
