@@ -14,9 +14,9 @@
 #include <QDirIterator>
 #include <QFile>
 
-#include <changerecorder.h>
-#include <entitydisplayattribute.h>
-#include <itemfetchscope.h>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/ItemFetchScope>
 
 #include <KLocalizedString>
 
@@ -53,7 +53,7 @@ void VCardDirResource::aboutToQuit()
     VcardDirResourceSettings::self()->save();
 }
 
-bool VCardDirResource::loadAddressees()
+void VCardDirResource::loadAddressees()
 {
     mAddressees.clear();
 
@@ -78,11 +78,42 @@ bool VCardDirResource::loadAddressees()
     }
 
     Q_EMIT status(Idle);
+}
+
+bool VCardDirResource::retrieveItems(const Akonadi::Item::List &items, const QSet<QByteArray> &parts)
+{
+    Q_UNUSED(parts);
+
+    Akonadi::Item::List resultItems;
+    resultItems.reserve(items.size());
+
+    for (const Akonadi::Item &item : items) {
+        Item newItem(item);
+        if (!doRetrieveItem(newItem)) {
+            return false;
+        }
+        resultItems.append(newItem);
+    }
+
+    itemsRetrieved(resultItems);
 
     return true;
 }
 
 bool VCardDirResource::retrieveItem(const Akonadi::Item &item, const QSet<QByteArray> &)
+{
+    Item newItem(item);
+
+    if (!doRetrieveItem(newItem)) {
+        return false;
+    }
+
+    itemRetrieved(newItem);
+
+    return true;
+}
+
+bool VCardDirResource::doRetrieveItem(Akonadi::Item &item)
 {
     const QString remoteId = item.remoteId();
     if (!mAddressees.contains(remoteId)) {
@@ -90,9 +121,7 @@ bool VCardDirResource::retrieveItem(const Akonadi::Item &item, const QSet<QByteA
         return false;
     }
 
-    Item newItem(item);
-    newItem.setPayload<KContacts::Addressee>(mAddressees.value(remoteId));
-    itemRetrieved(newItem);
+    item.setPayload<KContacts::Addressee>(mAddressees.value(remoteId));
 
     return true;
 }
